@@ -22,6 +22,14 @@
 #ifndef GTK_SOURCE_LANGUAGE_MANAGER_H
 #define GTK_SOURCE_LANGUAGE_MANAGER_H
 
+#if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
+#  if defined (__GNUC__)
+#    warning "Only <gtksourceview/gtksource.h> can be included directly."
+#  elif defined (G_OS_WIN32)
+#    pragma message("Only <gtksourceview/gtksource.h> can be included directly.")
+#  endif
+#endif
+
 #include <gtksourceview/gtksourcetypes.h>
 
 G_BEGIN_DECLS
