@@ -19,8 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_TYPES_PRIVATE_H__
-#define __GTK_SOURCE_TYPES_PRIVATE_H__
+#ifndef GTK_SOURCE_TYPES_PRIVATE_H
+#define GTK_SOURCE_TYPES_PRIVATE_H
 
 #include <glib.h>
 
@@ -48,4 +48,4 @@ typedef struct _GtkSourceUndoManagerDefault	GtkSourceUndoManagerDefault;
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_TYPES_PRIVATE_H__ */
+#endif /* GTK_SOURCE_TYPES_PRIVATE_H */
