@@ -19,10 +19,11 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_VIEW_UTILS_H__
-#define __GTK_SOURCE_VIEW_UTILS_H__
+#ifndef GTK_SOURCE_VIEW_UTILS_H
+#define GTK_SOURCE_VIEW_UTILS_H
 
 #include <glib.h>
+#include <pango/pango.h>
 
 G_BEGIN_DECLS
 
@@ -38,6 +39,9 @@ GSList 	 *_gtk_source_view_get_file_list    (gchar       **path,
 G_GNUC_INTERNAL
 gint	 _gtk_source_string_to_int	    (const gchar *str);
 
+G_GNUC_INTERNAL
+gchar	*_gtk_source_pango_font_description_to_css (const PangoFontDescription *font_desc);
+
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_VIEW_UTILS_H__ */
+#endif /* GTK_SOURCE_VIEW_UTILS_H */
