@@ -21,8 +21,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <gtk/gtk.h>
-#include "gtksourceview/gtksourceregion.h"
+#include <gtksourceview/gtksource.h>
 
 static void
 test_region (void)
